@@ -77,7 +77,34 @@ return array (
                     'type' => 'string',
                     'location' => 'json',
                     'minLength' => 1,
-                    'maxLength' => 1024,
+                ),
+                'parameterValues' => array(
+                    'type' => 'array',
+                    'location' => 'json',
+                    'items' => array(
+                        'name' => 'ParameterValue',
+                        'type' => 'object',
+                        'properties' => array(
+                            'id' => array(
+                                'required' => true,
+                                'type' => 'string',
+                                'minLength' => 1,
+                            ),
+                            'stringValue' => array(
+                                'required' => true,
+                                'type' => 'string',
+                            ),
+                        ),
+                    ),
+                ),
+                'startTimestamp' => array(
+                    'type' => array(
+                        'object',
+                        'string',
+                        'integer',
+                    ),
+                    'format' => 'date-time',
+                    'location' => 'json',
                 ),
             ),
             'errorResponses' => array(
@@ -99,6 +126,74 @@ return array (
                 ),
             ),
         ),
+        'AddTags' => array(
+            'httpMethod' => 'POST',
+            'uri' => '/',
+            'class' => 'Aws\\Common\\Command\\JsonCommand',
+            'responseClass' => 'EmptyOutput',
+            'responseType' => 'model',
+            'parameters' => array(
+                'Content-Type' => array(
+                    'static' => true,
+                    'location' => 'header',
+                    'default' => 'application/x-amz-json-1.1',
+                ),
+                'command.expects' => array(
+                    'static' => true,
+                    'default' => 'application/json',
+                ),
+                'X-Amz-Target' => array(
+                    'static' => true,
+                    'location' => 'header',
+                    'default' => 'DataPipeline.AddTags',
+                ),
+                'pipelineId' => array(
+                    'required' => true,
+                    'type' => 'string',
+                    'location' => 'json',
+                    'minLength' => 1,
+                ),
+                'tags' => array(
+                    'required' => true,
+                    'type' => 'array',
+                    'location' => 'json',
+                    'maxItems' => 10,
+                    'items' => array(
+                        'name' => 'Tag',
+                        'type' => 'object',
+                        'properties' => array(
+                            'key' => array(
+                                'required' => true,
+                                'type' => 'string',
+                                'minLength' => 1,
+                            ),
+                            'value' => array(
+                                'required' => true,
+                                'type' => 'string',
+                            ),
+                        ),
+                    ),
+                ),
+            ),
+            'errorResponses' => array(
+                array(
+                    'reason' => 'An internal service error occurred.',
+                    'class' => 'InternalServiceErrorException',
+                ),
+                array(
+                    'reason' => 'The request was not valid. Verify that your request was properly formatted, that the signature was generated with the correct credentials, and that you haven\'t exceeded any of the service limits for your account.',
+                    'class' => 'InvalidRequestException',
+                ),
+                array(
+                    'reason' => 'The specified pipeline was not found. Verify that you used the correct user and account identifiers.',
+                    'class' => 'PipelineNotFoundException',
+                ),
+                array(
+                    'reason' => 'The specified pipeline has been deleted.',
+                    'class' => 'PipelineDeletedException',
+                ),
+            ),
+        ),
         'CreatePipeline' => array(
             'httpMethod' => 'POST',
             'uri' => '/',
@@ -125,19 +220,36 @@ return array (
                     'type' => 'string',
                     'location' => 'json',
                     'minLength' => 1,
-                    'maxLength' => 1024,
                 ),
                 'uniqueId' => array(
                     'required' => true,
                     'type' => 'string',
                     'location' => 'json',
                     'minLength' => 1,
-                    'maxLength' => 1024,
                 ),
                 'description' => array(
                     'type' => 'string',
                     'location' => 'json',
-                    'maxLength' => 1024,
+                ),
+                'tags' => array(
+                    'type' => 'array',
+                    'location' => 'json',
+                    'maxItems' => 10,
+                    'items' => array(
+                        'name' => 'Tag',
+                        'type' => 'object',
+                        'properties' => array(
+                            'key' => array(
+                                'required' => true,
+                                'type' => 'string',
+                                'minLength' => 1,
+                            ),
+                            'value' => array(
+                                'required' => true,
+                                'type' => 'string',
+                            ),
+                        ),
+                    ),
                 ),
             ),
             'errorResponses' => array(
@@ -151,6 +263,58 @@ return array (
                 ),
             ),
         ),
+        'DeactivatePipeline' => array(
+            'httpMethod' => 'POST',
+            'uri' => '/',
+            'class' => 'Aws\\Common\\Command\\JsonCommand',
+            'responseClass' => 'EmptyOutput',
+            'responseType' => 'model',
+            'parameters' => array(
+                'Content-Type' => array(
+                    'static' => true,
+                    'location' => 'header',
+                    'default' => 'application/x-amz-json-1.1',
+                ),
+                'command.expects' => array(
+                    'static' => true,
+                    'default' => 'application/json',
+                ),
+                'X-Amz-Target' => array(
+                    'static' => true,
+                    'location' => 'header',
+                    'default' => 'DataPipeline.DeactivatePipeline',
+                ),
+                'pipelineId' => array(
+                    'required' => true,
+                    'type' => 'string',
+                    'location' => 'json',
+                    'minLength' => 1,
+                ),
+                'cancelActive' => array(
+                    'type' => 'boolean',
+                    'format' => 'boolean-string',
+                    'location' => 'json',
+                ),
+            ),
+            'errorResponses' => array(
+                array(
+                    'reason' => 'The specified pipeline was not found. Verify that you used the correct user and account identifiers.',
+                    'class' => 'PipelineNotFoundException',
+                ),
+                array(
+                    'reason' => 'The specified pipeline has been deleted.',
+                    'class' => 'PipelineDeletedException',
+                ),
+                array(
+                    'reason' => 'An internal service error occurred.',
+                    'class' => 'InternalServiceErrorException',
+                ),
+                array(
+                    'reason' => 'The request was not valid. Verify that your request was properly formatted, that the signature was generated with the correct credentials, and that you haven\'t exceeded any of the service limits for your account.',
+                    'class' => 'InvalidRequestException',
+                ),
+            ),
+        ),
         'DeletePipeline' => array(
             'httpMethod' => 'POST',
             'uri' => '/',
@@ -177,7 +341,6 @@ return array (
                     'type' => 'string',
                     'location' => 'json',
                     'minLength' => 1,
-                    'maxLength' => 1024,
                 ),
             ),
             'errorResponses' => array(
@@ -221,7 +384,6 @@ return array (
                     'type' => 'string',
                     'location' => 'json',
                     'minLength' => 1,
-                    'maxLength' => 1024,
                 ),
                 'objectIds' => array(
                     'required' => true,
@@ -231,7 +393,6 @@ return array (
                         'name' => 'id',
                         'type' => 'string',
                         'minLength' => 1,
-                        'maxLength' => 1024,
                     ),
                 ),
                 'evaluateExpressions' => array(
@@ -242,7 +403,6 @@ return array (
                 'marker' => array(
                     'type' => 'string',
                     'location' => 'json',
-                    'maxLength' => 1024,
                 ),
             ),
             'errorResponses' => array(
@@ -293,7 +453,6 @@ return array (
                         'name' => 'id',
                         'type' => 'string',
                         'minLength' => 1,
-                        'maxLength' => 1024,
                     ),
                 ),
             ),
@@ -342,20 +501,17 @@ return array (
                     'type' => 'string',
                     'location' => 'json',
                     'minLength' => 1,
-                    'maxLength' => 1024,
                 ),
                 'objectId' => array(
                     'required' => true,
                     'type' => 'string',
                     'location' => 'json',
                     'minLength' => 1,
-                    'maxLength' => 1024,
                 ),
                 'expression' => array(
                     'required' => true,
                     'type' => 'string',
                     'location' => 'json',
-                    'maxLength' => 20971520,
                 ),
             ),
             'errorResponses' => array(
@@ -407,12 +563,10 @@ return array (
                     'type' => 'string',
                     'location' => 'json',
                     'minLength' => 1,
-                    'maxLength' => 1024,
                 ),
                 'version' => array(
                     'type' => 'string',
                     'location' => 'json',
-                    'maxLength' => 1024,
                 ),
             ),
             'errorResponses' => array(
@@ -458,7 +612,6 @@ return array (
                 'marker' => array(
                     'type' => 'string',
                     'location' => 'json',
-                    'maxLength' => 1024,
                 ),
             ),
             'errorResponses' => array(
@@ -497,13 +650,11 @@ return array (
                     'required' => true,
                     'type' => 'string',
                     'location' => 'json',
-                    'maxLength' => 1024,
                 ),
                 'hostname' => array(
                     'type' => 'string',
                     'location' => 'json',
                     'minLength' => 1,
-                    'maxLength' => 1024,
                 ),
                 'instanceIdentity' => array(
                     'type' => 'object',
@@ -511,11 +662,9 @@ return array (
                     'properties' => array(
                         'document' => array(
                             'type' => 'string',
-                            'maxLength' => 1024,
                         ),
                         'signature' => array(
                             'type' => 'string',
-                            'maxLength' => 1024,
                         ),
                     ),
                 ),
@@ -561,7 +710,6 @@ return array (
                     'type' => 'string',
                     'location' => 'json',
                     'minLength' => 1,
-                    'maxLength' => 1024,
                 ),
                 'pipelineObjects' => array(
                     'required' => true,
@@ -575,13 +723,11 @@ return array (
                                 'required' => true,
                                 'type' => 'string',
                                 'minLength' => 1,
-                                'maxLength' => 1024,
                             ),
                             'name' => array(
                                 'required' => true,
                                 'type' => 'string',
                                 'minLength' => 1,
-                                'maxLength' => 1024,
                             ),
                             'fields' => array(
                                 'required' => true,
@@ -594,16 +740,13 @@ return array (
                                             'required' => true,
                                             'type' => 'string',
                                             'minLength' => 1,
-                                            'maxLength' => 256,
                                         ),
                                         'stringValue' => array(
                                             'type' => 'string',
-                                            'maxLength' => 10240,
                                         ),
                                         'refValue' => array(
                                             'type' => 'string',
                                             'minLength' => 1,
-                                            'maxLength' => 256,
                                         ),
                                     ),
                                 ),
@@ -611,6 +754,59 @@ return array (
                         ),
                     ),
                 ),
+                'parameterObjects' => array(
+                    'type' => 'array',
+                    'location' => 'json',
+                    'items' => array(
+                        'name' => 'ParameterObject',
+                        'type' => 'object',
+                        'properties' => array(
+                            'id' => array(
+                                'required' => true,
+                                'type' => 'string',
+                                'minLength' => 1,
+                            ),
+                            'attributes' => array(
+                                'required' => true,
+                                'type' => 'array',
+                                'items' => array(
+                                    'name' => 'ParameterAttribute',
+                                    'type' => 'object',
+                                    'properties' => array(
+                                        'key' => array(
+                                            'required' => true,
+                                            'type' => 'string',
+                                            'minLength' => 1,
+                                        ),
+                                        'stringValue' => array(
+                                            'required' => true,
+                                            'type' => 'string',
+                                        ),
+                                    ),
+                                ),
+                            ),
+                        ),
+                    ),
+                ),
+                'parameterValues' => array(
+                    'type' => 'array',
+                    'location' => 'json',
+                    'items' => array(
+                        'name' => 'ParameterValue',
+                        'type' => 'object',
+                        'properties' => array(
+                            'id' => array(
+                                'required' => true,
+                                'type' => 'string',
+                                'minLength' => 1,
+                            ),
+                            'stringValue' => array(
+                                'required' => true,
+                                'type' => 'string',
+                            ),
+                        ),
+                    ),
+                ),
             ),
             'errorResponses' => array(
                 array(
@@ -657,7 +853,6 @@ return array (
                     'type' => 'string',
                     'location' => 'json',
                     'minLength' => 1,
-                    'maxLength' => 1024,
                 ),
                 'query' => array(
                     'type' => 'object',
@@ -671,7 +866,6 @@ return array (
                                 'properties' => array(
                                     'fieldName' => array(
                                         'type' => 'string',
-                                        'maxLength' => 1024,
                                     ),
                                     'operator' => array(
                                         'type' => 'object',
@@ -689,12 +883,10 @@ return array (
                     'required' => true,
                     'type' => 'string',
                     'location' => 'json',
-                    'maxLength' => 1024,
                 ),
                 'marker' => array(
                     'type' => 'string',
                     'location' => 'json',
-                    'maxLength' => 1024,
                 ),
                 'limit' => array(
                     'type' => 'numeric',
@@ -720,6 +912,62 @@ return array (
                 ),
             ),
         ),
+        'RemoveTags' => array(
+            'httpMethod' => 'POST',
+            'uri' => '/',
+            'class' => 'Aws\\Common\\Command\\JsonCommand',
+            'responseClass' => 'EmptyOutput',
+            'responseType' => 'model',
+            'parameters' => array(
+                'Content-Type' => array(
+                    'static' => true,
+                    'location' => 'header',
+                    'default' => 'application/x-amz-json-1.1',
+                ),
+                'command.expects' => array(
+                    'static' => true,
+                    'default' => 'application/json',
+                ),
+                'X-Amz-Target' => array(
+                    'static' => true,
+                    'location' => 'header',
+                    'default' => 'DataPipeline.RemoveTags',
+                ),
+                'pipelineId' => array(
+                    'required' => true,
+                    'type' => 'string',
+                    'location' => 'json',
+                    'minLength' => 1,
+                ),
+                'tagKeys' => array(
+                    'required' => true,
+                    'type' => 'array',
+                    'location' => 'json',
+                    'items' => array(
+                        'name' => 'string',
+                        'type' => 'string',
+                    ),
+                ),
+            ),
+            'errorResponses' => array(
+                array(
+                    'reason' => 'An internal service error occurred.',
+                    'class' => 'InternalServiceErrorException',
+                ),
+                array(
+                    'reason' => 'The request was not valid. Verify that your request was properly formatted, that the signature was generated with the correct credentials, and that you haven\'t exceeded any of the service limits for your account.',
+                    'class' => 'InvalidRequestException',
+                ),
+                array(
+                    'reason' => 'The specified pipeline was not found. Verify that you used the correct user and account identifiers.',
+                    'class' => 'PipelineNotFoundException',
+                ),
+                array(
+                    'reason' => 'The specified pipeline has been deleted.',
+                    'class' => 'PipelineDeletedException',
+                ),
+            ),
+        ),
         'ReportTaskProgress' => array(
             'httpMethod' => 'POST',
             'uri' => '/',
@@ -746,7 +994,28 @@ return array (
                     'type' => 'string',
                     'location' => 'json',
                     'minLength' => 1,
-                    'maxLength' => 2048,
+                ),
+                'fields' => array(
+                    'type' => 'array',
+                    'location' => 'json',
+                    'items' => array(
+                        'name' => 'Field',
+                        'type' => 'object',
+                        'properties' => array(
+                            'key' => array(
+                                'required' => true,
+                                'type' => 'string',
+                                'minLength' => 1,
+                            ),
+                            'stringValue' => array(
+                                'type' => 'string',
+                            ),
+                            'refValue' => array(
+                                'type' => 'string',
+                                'minLength' => 1,
+                            ),
+                        ),
+                    ),
                 ),
             ),
             'errorResponses' => array(
@@ -798,18 +1067,15 @@ return array (
                     'type' => 'string',
                     'location' => 'json',
                     'minLength' => 1,
-                    'maxLength' => 1024,
                 ),
                 'workerGroup' => array(
                     'type' => 'string',
                     'location' => 'json',
-                    'maxLength' => 1024,
                 ),
                 'hostname' => array(
                     'type' => 'string',
                     'location' => 'json',
                     'minLength' => 1,
-                    'maxLength' => 1024,
                 ),
             ),
             'errorResponses' => array(
@@ -849,7 +1115,6 @@ return array (
                     'type' => 'string',
                     'location' => 'json',
                     'minLength' => 1,
-                    'maxLength' => 1024,
                 ),
                 'objectIds' => array(
                     'required' => true,
@@ -859,14 +1124,12 @@ return array (
                         'name' => 'id',
                         'type' => 'string',
                         'minLength' => 1,
-                        'maxLength' => 1024,
                     ),
                 ),
                 'status' => array(
                     'required' => true,
                     'type' => 'string',
                     'location' => 'json',
-                    'maxLength' => 1024,
                 ),
             ),
             'errorResponses' => array(
@@ -914,7 +1177,6 @@ return array (
                     'type' => 'string',
                     'location' => 'json',
                     'minLength' => 1,
-                    'maxLength' => 2048,
                 ),
                 'taskStatus' => array(
                     'required' => true,
@@ -924,7 +1186,6 @@ return array (
                 'errorId' => array(
                     'type' => 'string',
                     'location' => 'json',
-                    'maxLength' => 1024,
                 ),
                 'errorMessage' => array(
                     'type' => 'string',
@@ -933,7 +1194,6 @@ return array (
                 'errorStackTrace' => array(
                     'type' => 'string',
                     'location' => 'json',
-                    'maxLength' => 1024,
                 ),
             ),
             'errorResponses' => array(
@@ -985,7 +1245,6 @@ return array (
                     'type' => 'string',
                     'location' => 'json',
                     'minLength' => 1,
-                    'maxLength' => 1024,
                 ),
                 'pipelineObjects' => array(
                     'required' => true,
@@ -999,13 +1258,11 @@ return array (
                                 'required' => true,
                                 'type' => 'string',
                                 'minLength' => 1,
-                                'maxLength' => 1024,
                             ),
                             'name' => array(
                                 'required' => true,
                                 'type' => 'string',
                                 'minLength' => 1,
-                                'maxLength' => 1024,
                             ),
                             'fields' => array(
                                 'required' => true,
@@ -1018,16 +1275,13 @@ return array (
                                             'required' => true,
                                             'type' => 'string',
                                             'minLength' => 1,
-                                            'maxLength' => 256,
                                         ),
                                         'stringValue' => array(
                                             'type' => 'string',
-                                            'maxLength' => 10240,
                                         ),
                                         'refValue' => array(
                                             'type' => 'string',
                                             'minLength' => 1,
-                                            'maxLength' => 256,
                                         ),
                                     ),
                                 ),
@@ -1035,6 +1289,59 @@ return array (
                         ),
                     ),
                 ),
+                'parameterObjects' => array(
+                    'type' => 'array',
+                    'location' => 'json',
+                    'items' => array(
+                        'name' => 'ParameterObject',
+                        'type' => 'object',
+                        'properties' => array(
+                            'id' => array(
+                                'required' => true,
+                                'type' => 'string',
+                                'minLength' => 1,
+                            ),
+                            'attributes' => array(
+                                'required' => true,
+                                'type' => 'array',
+                                'items' => array(
+                                    'name' => 'ParameterAttribute',
+                                    'type' => 'object',
+                                    'properties' => array(
+                                        'key' => array(
+                                            'required' => true,
+                                            'type' => 'string',
+                                            'minLength' => 1,
+                                        ),
+                                        'stringValue' => array(
+                                            'required' => true,
+                                            'type' => 'string',
+                                        ),
+                                    ),
+                                ),
+                            ),
+                        ),
+                    ),
+                ),
+                'parameterValues' => array(
+                    'type' => 'array',
+                    'location' => 'json',
+                    'items' => array(
+                        'name' => 'ParameterValue',
+                        'type' => 'object',
+                        'properties' => array(
+                            'id' => array(
+                                'required' => true,
+                                'type' => 'string',
+                                'minLength' => 1,
+                            ),
+                            'stringValue' => array(
+                                'required' => true,
+                                'type' => 'string',
+                            ),
+                        ),
+                    ),
+                ),
             ),
             'errorResponses' => array(
                 array(
@@ -1157,6 +1464,21 @@ return array (
                             'description' => array(
                                 'type' => 'string',
                             ),
+                            'tags' => array(
+                                'type' => 'array',
+                                'items' => array(
+                                    'name' => 'Tag',
+                                    'type' => 'object',
+                                    'properties' => array(
+                                        'key' => array(
+                                            'type' => 'string',
+                                        ),
+                                        'value' => array(
+                                            'type' => 'string',
+                                        ),
+                                    ),
+                                ),
+                            ),
                         ),
                     ),
                 ),
@@ -1210,6 +1532,50 @@ return array (
                         ),
                     ),
                 ),
+                'parameterObjects' => array(
+                    'type' => 'array',
+                    'location' => 'json',
+                    'items' => array(
+                        'name' => 'ParameterObject',
+                        'type' => 'object',
+                        'properties' => array(
+                            'id' => array(
+                                'type' => 'string',
+                            ),
+                            'attributes' => array(
+                                'type' => 'array',
+                                'items' => array(
+                                    'name' => 'ParameterAttribute',
+                                    'type' => 'object',
+                                    'properties' => array(
+                                        'key' => array(
+                                            'type' => 'string',
+                                        ),
+                                        'stringValue' => array(
+                                            'type' => 'string',
+                                        ),
+                                    ),
+                                ),
+                            ),
+                        ),
+                    ),
+                ),
+                'parameterValues' => array(
+                    'type' => 'array',
+                    'location' => 'json',
+                    'items' => array(
+                        'name' => 'ParameterValue',
+                        'type' => 'object',
+                        'properties' => array(
+                            'id' => array(
+                                'type' => 'string',
+                            ),
+                            'stringValue' => array(
+                                'type' => 'string',
+                            ),
+                        ),
+                    ),
+                ),
             ),
         ),
         'ListPipelinesOutput' => array(
