@@ -1,4 +1,18 @@
 <?php
+/**
+ * Copyright 2010-2013 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License").
+ * You may not use this file except in compliance with the License.
+ * A copy of the License is located at
+ *
+ * http://aws.amazon.com/apache2.0
+ *
+ * or in the "license" file accompanying this file. This file is distributed
+ * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
+ * express or implied. See the License for the specific language governing
+ * permissions and limitations under the License.
+ */
 
 return array (
     'apiVersion' => '2015-04-08',
@@ -49,12 +63,22 @@ return array (
                                 'required' => true,
                                 'type' => 'string',
                                 'minLength' => 1,
-                                'maxLength' => 63,
                             ),
                             'BundleId' => array(
                                 'required' => true,
                                 'type' => 'string',
                             ),
+                            'VolumeEncryptionKey' => array(
+                                'type' => 'string',
+                            ),
+                            'UserVolumeEncryptionEnabled' => array(
+                                'type' => 'boolean',
+                                'format' => 'boolean-string',
+                            ),
+                            'RootVolumeEncryptionEnabled' => array(
+                                'type' => 'boolean',
+                                'format' => 'boolean-string',
+                            ),
                         ),
                     ),
                 ),
@@ -105,7 +129,6 @@ return array (
                     'type' => 'string',
                     'location' => 'json',
                     'minLength' => 1,
-                    'maxLength' => 63,
                 ),
             ),
             'errorResponses' => array(
@@ -150,7 +173,6 @@ return array (
                     'type' => 'string',
                     'location' => 'json',
                     'minLength' => 1,
-                    'maxLength' => 63,
                 ),
             ),
             'errorResponses' => array(
@@ -199,7 +221,6 @@ return array (
                     'type' => 'string',
                     'location' => 'json',
                     'minLength' => 1,
-                    'maxLength' => 63,
                 ),
                 'BundleId' => array(
                     'type' => 'string',
@@ -215,7 +236,6 @@ return array (
                     'type' => 'string',
                     'location' => 'json',
                     'minLength' => 1,
-                    'maxLength' => 63,
                 ),
             ),
             'errorResponses' => array(
@@ -374,6 +394,15 @@ return array (
                                     'BundleId' => array(
                                         'type' => 'string',
                                     ),
+                                    'VolumeEncryptionKey' => array(
+                                        'type' => 'string',
+                                    ),
+                                    'UserVolumeEncryptionEnabled' => array(
+                                        'type' => 'boolean',
+                                    ),
+                                    'RootVolumeEncryptionEnabled' => array(
+                                        'type' => 'boolean',
+                                    ),
                                 ),
                             ),
                             'ErrorCode' => array(
@@ -419,6 +448,18 @@ return array (
                             'ErrorCode' => array(
                                 'type' => 'string',
                             ),
+                            'ComputerName' => array(
+                                'type' => 'string',
+                            ),
+                            'VolumeEncryptionKey' => array(
+                                'type' => 'string',
+                            ),
+                            'UserVolumeEncryptionEnabled' => array(
+                                'type' => 'boolean',
+                            ),
+                            'RootVolumeEncryptionEnabled' => array(
+                                'type' => 'boolean',
+                            ),
                         ),
                     ),
                 ),
@@ -591,6 +632,18 @@ return array (
                             'ErrorCode' => array(
                                 'type' => 'string',
                             ),
+                            'ComputerName' => array(
+                                'type' => 'string',
+                            ),
+                            'VolumeEncryptionKey' => array(
+                                'type' => 'string',
+                            ),
+                            'UserVolumeEncryptionEnabled' => array(
+                                'type' => 'boolean',
+                            ),
+                            'RootVolumeEncryptionEnabled' => array(
+                                'type' => 'boolean',
+                            ),
                         ),
                     ),
                 ),
@@ -676,4 +729,22 @@ return array (
             ),
         ),
     ),
+    'iterators' => array(
+        'DescribeWorkspaceBundles' => array(
+            'input_token' => 'NextToken',
+            'output_token' => 'NextToken',
+            'result_key' => 'Bundles',
+        ),
+        'DescribeWorkspaceDirectories' => array(
+            'input_token' => 'NextToken',
+            'output_token' => 'NextToken',
+            'result_key' => 'Directories',
+        ),
+        'DescribeWorkspaces' => array(
+            'limit_key' => 'Limit',
+            'input_token' => 'NextToken',
+            'output_token' => 'NextToken',
+            'result_key' => 'Workspaces',
+        ),
+    ),
 );
